package com.usky.backend.controller;
import com.usky.backend.domain.MetricItemVo;
import com.usky.backend.domain.StatusVO;
import com.usky.backend.domain.request.HistoryQueryVo;
import com.usky.backend.domain.request.LastQueryVo;
import com.usky.backend.domain.response.HistoryResultVo;
import com.usky.backend.domain.response.LastResultVo;
import com.usky.backend.service.DataQueryService;
import com.usky.common.core.bean.ApiResult;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 *  数据统一查询 前端控制器
 * </p>
 *
 */
@RestController
@Api(tags = "数据统一查询")
@RequestMapping("/dataQuery")
public class DataQueryController {
    @Autowired
    private DataQueryService dataQueryService;

    /**
     * 获取单个设备单属性历史数据
     *
     * @param startTime 开始时间
     * @param endTime 结束时间
     * @param deviceId 设备Id
     * @param metric 属性
     * @param deviceType 设备类型编码（501、监控系统  502、门禁系统  503、梯控系统  504、机房系统  509、环境系统  510、照明系统）
     * @return
     */
    @GetMapping("/historyMetric")
    @ApiOperation("获取单个设备单属性历史数据")
    public ApiResult<HistoryResultVo> historyMetric(@RequestParam("startTime") String startTime,
                                              @RequestParam("endTime") String endTime,
                                              @RequestParam("deviceId") String deviceId,
                                              @RequestParam("metric") String metric,
                                              @RequestParam("deviceType") Integer deviceType) {
        return ApiResult.success(dataQueryService.historyMetric(deviceId,metric,startTime,endTime,deviceType));
    }

    @PostMapping("/historyMetrics")
    @ApiOperation("获取单个设备多属性历史数据")
    public ApiResult<List<HistoryResultVo>> historyMetrics(@RequestBody HistoryQueryVo historyQueryVo) {
        return ApiResult.success(dataQueryService.historyMetrics(historyQueryVo));
    }

    /**
     * 获取单个设备多指标实时数据
     * @param lastQueryVo
     * @return
     */
    @PostMapping("/last")
    @ApiOperation("获取单个设备多指标实时数据")
    public ApiResult<List<LastResultVo>> last(@RequestBody LastQueryVo lastQueryVo) {
        return ApiResult.success(dataQueryService.last(lastQueryVo));
    }

    /**
     * 查询设备状态
     * @return
     */
    @GetMapping("status")
    @ApiOperation(value = "查询设备状态",response = List.class)
    public ApiResult<List<StatusVO>> status(){
        return ApiResult.success(dataQueryService.status());
    }

}

