package com.usky.fire.controller.web;


import com.ruoyi.common.core.utils.poi.ExcelUtil;
import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.log.annotation.Log;
import com.usky.common.log.enums.BusinessType;
import com.usky.fire.service.AlarmElectricalFireService;
import com.usky.fire.service.vo.AlarmHiddenDangerVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.List;
import java.util.Map;

/**
 * <p>
 * 电气火灾隐患告警 前端控制器
 * </p>
 *
 * @author JCB
 * @since 2022-08-18
 */
@RestController
@RequestMapping("/alarmElectricalFire")
public class AlarmElectricalFireController {

    @Autowired
    private AlarmElectricalFireService alarmElectricalFireService;

    /**
     * 事件管理-隐患管理-不同类型隐患-列表查询
     *
     * @param systemType     系统类型(2.自动喷水灭火系统 3.消防给水及消火栓系统 4.防排烟系统 5.电气火灾系统 6.消防视频监控系统)
     * @param companyName    单位名称
     * @param handlingStatus 处理状态（0、未处理 1、已处理）
     * @param startDate      开始时间 格式：yyyy-MM-dd HH:mm:ss
     * @param endDate        结束时间 格式：yyyy-MM-dd HH:mm:ss
     * @param pageNum        当前页
     * @param pageSize       每页条数
     * @return
     */
    @GetMapping("alarmHiddenDangerList")
    public ApiResult<CommonPage<AlarmHiddenDangerVo>> alarmHiddenDangerList(@RequestParam(value = "systemType") Integer systemType,
                                                                            @RequestParam(value = "companyName", required = false) String companyName,
                                                                            @RequestParam(value = "handlingStatus", required = false) Integer handlingStatus,
                                                                            @RequestParam(value = "startDate", required = false) String startDate,
                                                                            @RequestParam(value = "endDate", required = false) String endDate,
                                                                            @RequestParam(value = "pageNum", required = false, defaultValue = "1") Integer pageNum,
                                                                            @RequestParam(value = "pageSize", required = false, defaultValue = "10") Integer pageSize) {
        return ApiResult.success(alarmElectricalFireService.alarmHiddenDangerList(systemType, companyName, handlingStatus, startDate, endDate, pageNum, pageSize));
    }

    /**
     * 事件管理-隐患管理-不同类型隐患-左侧数据统计
     *
     * @param systemType  系统类型(2.自动喷水灭火系统 3.消防给水及消火栓系统 4.防排烟系统 5.电气火灾系统 6.消防视频监控系统)
     * @param companyName 单位名称
     * @param startDate   开始时间 格式：yyyy-MM-dd HH:mm:ss
     * @param endDate     结束时间 格式：yyyy-MM-dd HH:mm:ss
     * @return
     */
    @GetMapping("hiddenDangerStatistics")
    public ApiResult<Map<String, Object>> hiddenDangerStatistics(@RequestParam(value = "systemType") Integer systemType,
                                                                 @RequestParam(value = "companyName", required = false) String companyName,
                                                                 @RequestParam(value = "startDate", required = false) String startDate,
                                                                 @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(alarmElectricalFireService.hiddenDangerStatistics(systemType, companyName, startDate, endDate));
    }


    /**
     * 事件管理-隐患管理-不同类型隐患-统计图数据查询
     *
     * @param systemType 系统类型(2.自动喷水灭火系统 3.消防给水及消火栓系统 4.防排烟系统 5.电气火灾系统 6.消防视频监控系统)
     * @param startDate  开始时间 格式：yyyy-MM-dd HH:mm:ss
     * @param endDate    结束时间 格式：yyyy-MM-dd HH:mm:ss
     * @return
     */
    @GetMapping("hiddenDangerStatisticalChart")
    public ApiResult<Map<String, Object>> hiddenDangerStatisticalChart(@RequestParam(value = "systemType") Integer systemType,
                                                                       @RequestParam(value = "startDate", required = false) String startDate,
                                                                       @RequestParam(value = "endDate", required = false) String endDate) {
        return ApiResult.success(alarmElectricalFireService.hiddenDangerStatisticalChart(systemType, startDate, endDate));
    }

    /**
     * 事件管理-隐患管理-不同类型隐患-告警处理
     *
     * @param alarmHiddenDangerVo
     * @return
     */
    @Log(title = "隐患管理-告警处理", businessType = BusinessType.UPDATE)
    @PutMapping("updateHiddenDanger")
    public ApiResult<Void> updateHiddenDanger(@RequestBody AlarmHiddenDangerVo alarmHiddenDangerVo) {
        alarmElectricalFireService.updateHiddenDanger(alarmHiddenDangerVo);
        return ApiResult.success();
    }

    /**
     * 事件管理-隐患管理-不同类型隐患-导出
     *
     * @param response
     * @param systemType     系统类型(2.自动喷水灭火系统 3.消防给水及消火栓系统 4.防排烟系统 5.电气火灾系统 6.消防视频监控系统)
     * @param companyName    单位名称
     * @param handlingStatus 处理状态（0、未处理 1、已处理）
     * @param startDate      开始时间 格式：yyyy-MM-dd HH:mm:ss
     * @param endDate        结束时间 格式：yyyy-MM-dd HH:mm:ss
     * @param exportTitle    标题
     * @throws IOException
     */
    @PostMapping("alarmHiddenDangerListExport")
    public void export(HttpServletResponse response,
                       @RequestParam(value = "systemType") Integer systemType,
                       @RequestParam(value = "companyName", required = false) String companyName,
                       @RequestParam(value = "handlingStatus", required = false) Integer handlingStatus,
                       @RequestParam(value = "startDate", required = false) String startDate,
                       @RequestParam(value = "endDate", required = false) String endDate,
                       @RequestParam(value = "exportTitle") String exportTitle) throws IOException {
        List<AlarmHiddenDangerVo> list = alarmElectricalFireService.alarmHiddenDangerListOne(systemType, companyName, handlingStatus, startDate, endDate);
        ExcelUtil<AlarmHiddenDangerVo> util = new ExcelUtil<AlarmHiddenDangerVo>(AlarmHiddenDangerVo.class);
        util.exportExcel(response, list, exportTitle, exportTitle);
    }
}

