package com.usky.iot.controller.web;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.toolkit.CollectionUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.usky.common.core.bean.ApiResult;
import com.usky.common.core.bean.CommonPage;
import com.usky.iot.domain.BaseFacilityDevice;
import com.usky.iot.domain.DmpDeviceInfo;
import com.usky.iot.service.DmpDeviceInfoService;
import com.usky.iot.service.vo.BaseFacilityDeviceVO;
import com.usky.iot.service.vo.DmpDeviceInfoRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;

import javax.servlet.http.HttpServletResponse;
import java.util.ArrayList;
import java.util.List;

/**
 * 设备信息表
 *
 * @author ya
 * @since 2022-10-08
 */
@RestController
@RequestMapping("/dmpDeviceInfo")
public class DmpDeviceInfoController {

    @Autowired
    private DmpDeviceInfoService dmpDeviceInfoService;

    /**
     * 新增
     * @param dmpDeviceInfo
     * @return
     */
    @PostMapping
    public ApiResult<Void> add(@RequestBody DmpDeviceInfo dmpDeviceInfo){
        dmpDeviceInfoService.add(dmpDeviceInfo);
        return ApiResult.success();
    }

    /**
     * 修改
     * @param dmpDeviceInfo
     * @return
     */
    @PutMapping
    public ApiResult<Void> edit(@RequestBody DmpDeviceInfo dmpDeviceInfo){
        dmpDeviceInfoService.update(dmpDeviceInfo);
        return ApiResult.success();
    }


    /**
     * 分页
     * @param dmpDeviceInfoRequest
     * @return
     */
    @PostMapping("/page")
    public ApiResult<CommonPage<DmpDeviceInfo>> page(@RequestBody DmpDeviceInfoRequest dmpDeviceInfoRequest)
    {
        return ApiResult.success(dmpDeviceInfoService.page(dmpDeviceInfoRequest));
    }

    /**
     * 删除记录
     */
    @DeleteMapping("/{id}")
    public ApiResult<Void> remove(@PathVariable("id") Integer id)
    {
        dmpDeviceInfoService.remove(id);
        return ApiResult.success();
    }

    /**
     * 批量导入
     * @param multipartFiles
     * @param productId
     * @return
     */
    @PostMapping("/addByFile")
    public ApiResult<Void> addByFile(@RequestParam(value = "file") MultipartFile multipartFiles,
                                     @RequestParam("productId") Integer productId){
        dmpDeviceInfoService.addByFile(productId,multipartFiles);
        return ApiResult.success();
    }

    /**
     * 导出
     * @param dmpDeviceInfoRequest
     * @param response
     * @return
     */
    @PostMapping("/export")
    public void export(@RequestBody DmpDeviceInfoRequest dmpDeviceInfoRequest, HttpServletResponse response){
        dmpDeviceInfoService.export(dmpDeviceInfoRequest,response);
    }
}

