package com.usky.park.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.park.domain.DmpDevice;
import com.usky.park.domain.EventEg;
import com.usky.park.mapper.EventEgMapper;
import com.usky.park.service.DmpDeviceService;
import com.usky.park.service.EventEgService;
import com.usky.common.mybatis.core.AbstractCrudService;
import java.util.Comparator;
import com.usky.park.service.vo.EventEgStatisticVO;
import org.bouncycastle.util.StringList;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 门禁历史通行记录表 服务实现类
 * </p>
 *
 * @author zyj
 * @since 2023-03-31
 */
@Service
public class EventEgServiceImpl extends AbstractCrudService<EventEgMapper, EventEg> implements EventEgService {
    @Autowired
    private DmpDeviceService deviceService;

    @Override
    public CommonPage<EventEg> eventEgList(String deviceName,String installAddress,String cardNo,String orgName,Integer eventType,Integer pageNum,Integer pageSize){
        IPage<EventEg> page = new Page<>(pageNum,pageSize);
        List<EventEg> list = new ArrayList<>();
        List<EventEg> list2 = new ArrayList<>();

        LambdaQueryWrapper<DmpDevice> queryWrapper1 = Wrappers.lambdaQuery();
        queryWrapper1.select(DmpDevice::getDeviceId)
                .eq(DmpDevice::getDeleteFlag,0)
                .eq(DmpDevice::getDeviceType,502);
        List<DmpDevice> deviceList = deviceService.list(queryWrapper1);
        if(deviceList.size() > 0){
            for(int i=0;i<deviceList.size();i++){
                LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
                queryWrapper.eq(EventEg::getDeviceId,deviceList.get(i).getDeviceId())
                        .like(StringUtils.isNotBlank(deviceName),EventEg::getDeviceName,deviceName)
                        .like(StringUtils.isNotBlank(installAddress),EventEg::getInstallAddress,installAddress)
                        .like(StringUtils.isNotBlank(cardNo),EventEg::getCardNo,cardNo)
                        .like(StringUtils.isNotBlank(orgName),EventEg::getOrgName,orgName)
                        .eq(eventType != null,EventEg::getEventType,eventType)
                        .orderByDesc(EventEg::getEventTime);
                List<EventEg> list1 = this.list(queryWrapper);
                if(list1.size()>0){
                    list.add(list1.get(0));

                }
            }

        }

        List<EventEg> objectList = new ArrayList<>();
        int total = 0;
        if(list.size() > 0){
            total = list.size();
        }
        int current = 0;
        if(pageNum != 0 && pageSize > 0){
            current = (pageNum - 1)*pageSize;
        }

        objectList = list.stream().skip(current).limit(pageSize).collect(Collectors.toList());
        objectList = objectList.stream().sorted(Comparator.comparing(EventEg::getEventTime).reversed()).collect(Collectors.toList());


        return new CommonPage<>(objectList,total,pageNum,pageSize);

    }

    @Override
    public CommonPage<EventEg> eventEgOne(String deviceId, String personName, String startDate, String endDate,Integer pageNum,Integer pageSize){
        IPage<EventEg> page = new Page<>(pageNum,pageSize);
        LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.eq(EventEg::getDeviceId,deviceId)
                .like(StringUtils.isNotBlank(personName),EventEg::getPersonName,personName)
                .between(StringUtils.isNotBlank(startDate) && StringUtils.isNotBlank(endDate),EventEg::getEventTime,startDate,endDate)
                .orderByDesc(EventEg::getId);
        page = this.page(page,queryWrapper);

        return new CommonPage<>(page.getRecords(),page.getTotal(),pageNum,pageSize);
    }

    @Override
    public List<EventEgStatisticVO> eventEgStatistic(List<String> enterDeviceId, List<String> outDeviceId, String startDate, String endDate){
        List<EventEgStatisticVO> list = new ArrayList<>();
        EventEgStatisticVO eventEgStatisticVO = new EventEgStatisticVO();
        eventEgStatisticVO.setEnterNum(numStatistic(enterDeviceId,startDate,endDate));
        eventEgStatisticVO.setOutNum(numStatistic(outDeviceId,startDate,endDate));
        list.add(eventEgStatisticVO);

        return list;
    }

    public Integer numStatistic(List<String> deviceId,String startDate,String endDate){
        Integer num = 0;
        LambdaQueryWrapper<EventEg> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.in(EventEg::getDeviceId,deviceId)
                .between(EventEg::getEventTime,startDate,endDate);
        num = this.count(queryWrapper);

        return num;
    }

}
