package com.usky.website.service.impl;

import cn.hutool.core.collection.CollectionUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.core.toolkit.StringUtils;
import com.baomidou.mybatisplus.core.toolkit.Wrappers;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.usky.common.core.bean.CommonPage;
import com.usky.common.mybatis.core.AbstractCrudService;
import com.usky.website.domain.SiteArticle;
import com.usky.website.domain.SiteCategory;
import com.usky.website.mapper.SiteArticleMapper;
import com.usky.website.mapper.SiteCategoryMapper;
import com.usky.website.service.SiteArticleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 官网_内容管理 服务实现类
 * </p>
 *
 * @author ya
 * @since 2022-08-31
 */
@Service
public class SiteArticleServiceImpl extends AbstractCrudService<SiteArticleMapper, SiteArticle> implements SiteArticleService {

    @Autowired
    private SiteCategoryMapper siteCategoryMapper;

    @Override
    public CommonPage<SiteArticle> siteArticleList(Integer categoryid, Integer id, String title, Integer pageNum, Integer pageSize) {
        IPage<SiteArticle> page = new Page<>(pageNum, pageSize);
        List<Integer> categoryidList = new ArrayList<>();
        if (categoryid != null && categoryid != 0) {
            if (categoryid == 18) {
                LambdaQueryWrapper<SiteCategory> queryWrapper1 = Wrappers.lambdaQuery();
                queryWrapper1.select(SiteCategory::getId)
                        .eq(SiteCategory::getPid, categoryid)
                        .eq(SiteCategory::getStatus, 1);
                List<SiteCategory> list = siteCategoryMapper.selectList(queryWrapper1);
                for (int i = 0; i < list.size(); i++) {
                    categoryidList.add(list.get(i).getId());
                }
            } else {
                categoryidList.add(categoryid);
            }
        }

        LambdaQueryWrapper<SiteCategory> queryWrapper1 = Wrappers.lambdaQuery();
        queryWrapper1.eq(SiteCategory::getStatus, 1)
                .in(CollectionUtil.isNotEmpty(categoryidList), SiteCategory::getId, categoryidList);
        List<SiteCategory> list = siteCategoryMapper.selectList(queryWrapper1);

        LambdaQueryWrapper<SiteArticle> queryWrapper = Wrappers.lambdaQuery();
        queryWrapper.in(CollectionUtil.isNotEmpty(categoryidList), SiteArticle::getCategoryid, categoryidList)
                .eq(id != null, SiteArticle::getId, id)
                .like(StringUtils.isNotBlank(title), SiteArticle::getTitle, title)
                .orderByDesc(SiteArticle::getIstop, SiteArticle::getId);
        page = this.page(page, queryWrapper);

        for (int i = 0; i < page.getRecords().size(); i++) {
            for (int j = 0; j < list.size(); j++) {
                if (page.getRecords().get(i).getCategoryid() == list.get(j).getId()) {
                    page.getRecords().get(i).setCategoryName(list.get(j).getCategoryName());
                }
            }
        }
        return new CommonPage<>(page.getRecords(), page.getTotal(), pageSize, pageNum);
    }

    @Override
    public void addSiteArticle(SiteArticle siteArticle) {
        siteArticle.setCreatedate(LocalDateTime.now());
        this.save(siteArticle);
    }

    @Override
    public void updateSiteArticle(SiteArticle siteArticle) {
        siteArticle.setModifydate(LocalDateTime.now());
        this.updateById(siteArticle);
    }

    @Override
    public void delSiteArticle(Integer id) {
        this.removeById(id);
    }
}
